# Python-based plotting utils for A3d models

Included are two python scripts, as well as their local dependencies (not
appearing in `ucbpy`) and data, for plotting UCB A3d models: one for plotting
in map view, and the othe for plotting cross-sections.

## Dependencies

Python packages:
* numpy / scipy
* matplotlib
* matplotlib's Basemap toolkit

Also depends on the `ucbpy` suite of python modules. See `../Python/` (the
`ucbpy` subdirectory of which should be added to your `PYTHONPATH`).

## Usage

### Maps

For plotting maps, one can use the `plot_maps.py` utility.

General configuration (figure size, map projection, save format, etc.) appears
in the "config" section near the top of `plot_maps.py`, while the model file
names (A3d and 1D reference), depths to plot, saturation levels, etc. are
supplied as command-line arguments. For a quick synopsis of the latter, run:

    $ ./plot_maps.py --help

For example, to plot Vs at 1000 and 1500 km, using saturation levels of 2% and
1.5% respectively, with the global mean removed at each depth:

    $ ./plot_maps.py --model Model-2.6S6X4-ZeroMean.A3d \
                     --ref-model Model-2.6S6X4-ZeroMean_1D \
		     --grid grid/grid.6 \
                     --param S --depths 1000:2.0,1500:1.5 --rmean

To plot with respect to a reference value *other* than the 1D reference model
or the global mean, we supply an additional reference value argument when
specifying the depths. For example, to plot Vs at 2800 km at a saturation level
of 3% but with respect to the PREM value at that depth:

    $ ./plot_maps.py --model Model-2.6S6X4-ZeroMean.A3d \
                     --ref-model Model-2.6S6X4-ZeroMean_1D \
                     --param S --depths 2800:3.0:7.265

### Cross sections

For plotting cross-sections, one can use the `plot_xsec.py` utility.

This script differs from the tool for plotting maps described above, in that
configuration is primarily handled in the script itself (there are no command
like arguments). This largely stems from the fact that cross-sections are a bit
less "automatic" than maps -- meaning, much more case-by-case configuration
must generally be done in order to attain the desired result.

General configuration appears in the "config" section near the top of the
script file, including information about the model to plot, depth range
considered, etc. See this section for detailed comments on available options.
The paths along which to evaluate the section are often defined
programmatically (for example, when plotting a series of sections normal to
Pacific APM).  Thus, paths are generated passed to the plotting functions from
the main `define_and_plot_xsecs()` routine. In the latter function, you can
find two examples: one of plotting a single great-circle section from two
lon/lat endpoints, and one more complex case in which we plot a series of
sections normal to Pacific APM.

By default, the simple single-path example (from Fukao and Obayashi, 2013) is
uncommented, while the more complex example is commented. This can easily be
reversed in the code. To run the code, simply invoke:

    $ ./plot_xsec.py

